@@ -105,6 +105,14 @@ class Revision:
         Returns a list of html tag names present in the content of the revision
         """
 
+        self.tags_str = mappers.map(
+            str, self.tags,
+            name=self._name + ".tags_str"
+        )
+        """
+        Returns a list of tags present in the content of the revision as strings
+        """
+
         self.templates = get_key(
             mwparserfromhell.nodes.Template, self.node_class_map,
             default=[],
@@ -122,6 +130,21 @@ class Revision:
         Returns a list of template names present in the content of the revision
         """
 
+        self.templates_str = mappers.map(
+            str, self.templates,
+            name=self._name + ".templates_str"
+        )
+        """
+        Returns a list of templates present in the content of the revision as strings
+        """
+        self.sections = Datasource(
+            self._name + ".section",
+            _extract_sections, depends_on=[self.wikicode]
+        )
+        """
+        Returns list of sections in the article as wikicode shared node list
+        """
+
     def heading_titles_matching(self, regex, name=None):
         """
         Constructs a :class:`revscoring.Datasource` that generates a `list` of
@@ -190,6 +213,20 @@ class Revision:
 
         return filters.regex_matching(regex, self.tag_names, name=name)
 
+    def tags_str_matching(self, regex, name=None):
+        """
+        Constructs a :class:`revscoring.Datasource` that returns all tags
+        that matches a regular expression as strings.
+        """
+        if not hasattr(regex, "pattern"):
+            regex = re.compile(regex, re.I)
+
+        if name is None:
+            name = "{0}({1})" \
+                   .format(self._name + ".tags_str_matching", regex.pattern)
+
+        return filters.regex_matching(regex, self.tags_str, name=name)
+
     def template_names_matching(self, regex, name=None):
         """
         Constructs a :class:`revscoring.Datasource` that returns all template
@@ -205,6 +242,21 @@ class Revision:
 
         return filters.regex_matching(regex, self.template_names, name=name)
 
+    def templates_str_matching(self, regex, name=None):
+        """
+        Constructs a :class:`revscoring.Datasource` that returns all templates
+        that matches a regular expression as strings.
+        """
+        if not hasattr(regex, "pattern"):
+            regex = re.compile(regex, re.I)
+
+        if name is None:
+            name = "{0}({1})" \
+                .format(self._name + ".templates_str_matching",
+                        regex.pattern)
+
+        return filters.regex_matching(regex, self.templates_str, name=name)
+
 
 def _process_wikicode(text):
     return mwparserfromhell.parse(text)
@@ -242,6 +294,10 @@ def _extract_template_name(template):
     return str(template.name)
 
 
+def _extract_sections(wikicode):
+    return wikicode.get_sections(flat=True)
+
+
 class HeadingOfLevel:
     def __init__(self, level):
         self.level = int(level)
