@@ -1,27 +1,26 @@
+import json
+from pkg_resources import resource_filename
+
 from .features import Dictionary, RegexMatches, Stemmed, Stopwords
-from .features.dictionary import utf16_cleanup
+from .features.dictionary import MultiDictChecker, load_dict, utf16_cleanup
 
 name = "english"
 
-try:
-    import enchant
-    enchant_dict = enchant.Dict("en")
-except enchant.errors.DictNotFoundError:
-    raise ImportError("No enchant-compatible dictionary found for 'en'.  " +
-                      "Consider installing 'myspell-en-au', " +
-                      "'myspell-en-gb', 'myspell-en-us' and/or " +
-                      "'myspell-en-za'.")
+multi_dict = MultiDictChecker(
+    load_dict('en_US', 'hunspell-en-us'),
+    load_dict('en_GB', 'hunspell-en-gb'),
+    load_dict('en_AU', 'hunspell-en-au'))
 
 
 def safe_dictionary_check(word):
-    return enchant_dict.check(utf16_cleanup(word))
+    return multi_dict.check(utf16_cleanup(word))
 
 
 dictionary = Dictionary(name + ".dictionary", safe_dictionary_check)
 """
 :class:`~revscoring.languages.features.Dictionary` features via
-:class:`enchant.Dict` "en". Provided by `myspell-en-au`, `myspell-en-gb`,
-`myspell-en-us`, and `myspell-en-za`.
+`enchant.Dict <https://github.com/rfk/pyenchant>`_ "en". Provided by
+`hunspell-en-au`, `hunspell-en-gb`, and `hunspell-en-us`.
 """
 
 try:
@@ -35,7 +34,7 @@ except LookupError:
 stopwords = Stopwords(name + ".stopwords", stopwords)
 """
 :class:`~revscoring.languages.features.Stopwords` features provided by
-:func:`nltk.corpus.stopwords` "english"
+`nltk.corpus.stopwords <https://www.nltk.org/api/nltk.corpus.html>`_ "english"
 """
 
 try:
@@ -146,7 +145,7 @@ badword detecting regexes.
 """
 
 informal_regexes = [
-    r"ain'?t", "a+we?some?(r|st)?",
+    r"ain'?t", r"a+we?some?(r|st)?",
     r"(b+l+a+h*)+",
     r"b+?o+?n+?e+?r+?",
     r"boobs?",
@@ -195,7 +194,7 @@ informal_regexes = [
     r"shouldn'?t",
     r"test +edit", r"t+?u+?r+?d+?s?\w*",
     r"wasn'?t",
-    r"w+[oua]+t+", r"wtf\w*", r"wh?[ua]+?t?[sz]+[ua]+p", "s+?u+?p+?",
+    r"w+[oua]+t+", r"wtf\w*", r"wh?[ua]+?t?[sz]+[ua]+p", r"s+?u+?p+?",
     r"wu+?z+?",
     r"won'?t",
     r"w+?o+?o+?f+?",
@@ -268,3 +267,13 @@ words_to_watch = RegexMatches(name + ".words_to_watch", words_to_watch_regexes)
 :class:`~revscoring.languages.features.RegexMatches` features via a list of
 problematic words and phrases for use in reference text
 """
+
+filepath = resource_filename('revscoring', 'assets/enwiktionary_idioms.txt')
+with open(filepath) as f:
+    idioms_regexes = [json.loads(line) for line in f]
+
+idioms = RegexMatches(name + ".idioms", idioms_regexes)
+"""
+:class:`~revscoring.languages.features.RegexMatches` features via a list of
+idioms from the `~assets/enwiktionary_idioms.txt` file
+"""
